analphipy.Phi\_hs
=================

.. currentmodule:: analphipy

.. autoclass:: Phi_hs

   
   ..
      .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:
   
      ~Phi_hs.__init__
      ~Phi_hs.asdict
      ~Phi_hs.assign
      ~Phi_hs.assign_min_numeric
      ~Phi_hs.cut
      ~Phi_hs.dphidr
      ~Phi_hs.lfs
      ~Phi_hs.minimize
      ~Phi_hs.new_like
      ~Phi_hs.phi
      ~Phi_hs.to_measures
      ~Phi_hs.to_nf
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree:
   
      ~Phi_hs.sig
      ~Phi_hs.phi_min
      ~Phi_hs.r_min
      ~Phi_hs.segments
   
   

   
   
   .. rubric:: Dunder Methods

   .. autosummary::
      :toctree:
   
      ~Phi_hs.__repr__
   
   